// Test case that compares a file generated by rust_xlsxwriter with a file
// created by Excel.
//
// SPDX-License-Identifier: MIT OR Apache-2.0
//
// Copyright 2022-2025, John McNamara, jmcnamara@cpan.org

use crate::common;
use rust_xlsxwriter::{Chart, ChartDataLabel, ChartType, Workbook, XlsxError};

// Create a rust_xlsxwriter file to compare against an Excel file.
fn create_new_xlsx_file_1(filename: &str) -> Result<(), XlsxError> {
    let mut workbook = Workbook::new();

    let worksheet = workbook.add_worksheet();

    // Add some test data for the chart(s).
    let data = [[1, 2, 3], [2, 4, 6], [3, 6, 9], [4, 8, 12], [5, 10, 15]];
    for (row_num, row_data) in data.iter().enumerate() {
        for (col_num, col_data) in row_data.iter().enumerate() {
            worksheet.write_number(row_num as u32, col_num as u16, *col_data)?;
        }
    }
    worksheet.write(0, 3, "foo")?;
    worksheet.write(1, 3, "bar")?;

    let data_labels = vec![
        ChartDataLabel::new().set_value("123").to_custom(),
        ChartDataLabel::new().set_value("abc").to_custom(),
        ChartDataLabel::default(),
        ChartDataLabel::new().set_value("=Sheet1!$D$1").to_custom(),
        ChartDataLabel::new().set_value("=Sheet1!$D$2").to_custom(),
    ];

    let mut chart = Chart::new(ChartType::Column);
    chart.set_axis_ids(48514944, 48516480);
    chart
        .add_series()
        .set_values(("Sheet1", 0, 0, 4, 0))
        .set_custom_data_labels(&data_labels);

    chart.add_series().set_values(("Sheet1", 0, 1, 4, 1));
    chart.add_series().set_values(("Sheet1", 0, 2, 4, 2));

    worksheet.insert_chart(8, 4, &chart)?;

    workbook.save(filename)?;

    Ok(())
}

// Create a rust_xlsxwriter file to compare against an Excel file. Test too many points.
fn create_new_xlsx_file_2(filename: &str) -> Result<(), XlsxError> {
    let mut workbook = Workbook::new();

    let worksheet = workbook.add_worksheet();

    // Add some test data for the chart(s).
    let data = [[1, 2, 3], [2, 4, 6], [3, 6, 9], [4, 8, 12], [5, 10, 15]];
    for (row_num, row_data) in data.iter().enumerate() {
        for (col_num, col_data) in row_data.iter().enumerate() {
            worksheet.write_number(row_num as u32, col_num as u16, *col_data)?;
        }
    }
    worksheet.write(0, 3, "foo")?;
    worksheet.write(1, 3, "bar")?;

    let data_labels = vec![
        ChartDataLabel::new().set_value("123").to_custom(),
        ChartDataLabel::new().set_value("abc").to_custom(),
        ChartDataLabel::default(),
        ChartDataLabel::new().set_value("=Sheet1!$D$1").to_custom(),
        ChartDataLabel::new().set_value("=Sheet1!$D$2").to_custom(),
        ChartDataLabel::new().set_value("123").to_custom(), // Exceeds number of data points. Should be ignored.
        ChartDataLabel::new().set_value("123").to_custom(), // Exceeds number of data points. Should be ignored.
        ChartDataLabel::new().set_value("123").to_custom(), // Exceeds number of data points. Should be ignored.
    ];

    let mut chart = Chart::new(ChartType::Column);
    chart.set_axis_ids(48514944, 48516480);
    chart
        .add_series()
        .set_values(("Sheet1", 0, 0, 4, 0))
        .set_custom_data_labels(&data_labels);

    chart.add_series().set_values(("Sheet1", 0, 1, 4, 1));
    chart.add_series().set_values(("Sheet1", 0, 2, 4, 2));

    worksheet.insert_chart(8, 4, &chart)?;

    workbook.save(filename)?;

    Ok(())
}

#[test]
fn test_chart_data_labels28_1() {
    let test_runner = common::TestRunner::new()
        .set_name("chart_data_labels28")
        .set_function(create_new_xlsx_file_1)
        .unique("1")
        .initialize();

    test_runner.assert_eq();
    test_runner.cleanup();
}

#[test]
fn test_chart_data_labels28_2() {
    let test_runner = common::TestRunner::new()
        .set_name("chart_data_labels28")
        .set_function(create_new_xlsx_file_2)
        .unique("2")
        .initialize();

    test_runner.assert_eq();
    test_runner.cleanup();
}
