// Test case that compares a file generated by rust_xlsxwriter with a file
// created by Excel.
//
// SPDX-License-Identifier: MIT OR Apache-2.0
//
// Copyright 2022-2025, John McNamara, jmcnamara@cpan.org

use crate::common;
use rust_xlsxwriter::{Image, Workbook, XlsxError};

// Create a rust_xlsxwriter file to compare against an Excel file.
fn create_new_xlsx_file(filename: &str) -> Result<(), XlsxError> {
    let mut workbook = Workbook::new();

    let worksheet = workbook.add_worksheet();

    let image = Image::new("tests/input/images/blue.png")?.set_alt_text("blue.png");

    worksheet.insert_image(0, 0, &image)?;

    let image = Image::new("tests/input/images/red.jpg")?
        .set_alt_text("red.jpg")
        .set_url("https://github.com/jmcnamara")?;

    worksheet.insert_image(2, 1, &image)?;

    let image = Image::new("tests/input/images/yellow.jpg")?.set_alt_text("yellow.jpg");

    worksheet.insert_image(4, 3, &image)?;

    let image = Image::new("tests/input/images/grey.png")?
        .set_alt_text("grey.png")
        .set_url("https://github.com")?;

    worksheet.insert_image(8, 5, &image)?;

    workbook.save(filename)?;

    Ok(())
}

#[test]
fn test_hyperlink34() {
    let test_runner = common::TestRunner::new()
        .set_name("hyperlink34")
        .set_function(create_new_xlsx_file)
        .initialize();

    test_runner.assert_eq();
    test_runner.cleanup();
}
